<?php
class DemoReservaController extends Zend_Controller_Action
{
    public function  preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        if(!$auth->hasIdentity()){
            $this->_redirect('/demo-acceso');
        } else {
            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->type_session!='demo') {
                $this->_redirect('/');
            }
        }
    }

    public function init()
    {
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $response = $this->getResponse();
        $response->insert('header', $this->view->render('header-demo.phtml'));
        $response->insert('footer', $this->view->render('footer.phtml'));
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') { 
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = ''; 
        }

        $this->view->title = "ExpressAuto S.p.A. - Reservar hora de atención";

        $request = $this->getRequest();
        $form = new Default_Form_Reserva('/demo/index#reservas');
        $form->setAction('/demo-reserva/new');
        $form->vehiculo->addMultiOptions(Default_Model_DemoVehiculo::getPairsToSelect($this->usuario->cliente));
        
        if ($this->_request->isPost()) { 
            if ($form->isValid($request->getPost())) {

                try {

                    $reserva = new Default_Model_DemoReserva();

                    $row_reserva = $reserva->createRow();
                    $row_reserva->cliente = $this->usuario->cliente;
                    $row_reserva->vehiculo = $form->getValue('vehiculo');
                    $row_reserva->usuario_id = $this->usuario->id;
                    $row_reserva->fecha = $form->getValue('fecha');
                    $row_reserva->hora = $form->getValue('hora');
                    if($form->getValue('comentarios')=='') {
                        $row_reserva->comentarios = NULL;
                    } else {
                        $row_reserva->comentarios = $form->getValue('comentarios');
                    }
                    $row_reserva->tipo = $form->getValue('tipo');
                    $row_reserva->save();
                    $mSession->mensajes[] = 'La reserva fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/demo/index#reservas');

                } catch (Exception $e) {
                    $mSession->mensajes[] = 'OCurrió un error al intentar crear la reserva.';
                    $mSession->claseMensaje = 'errors';
                    $this->_redirect('/demo/index#reservas');
                }
            } else {
                $this->view->mensajes[] = 'La información ingresada no es válida, por favor verifique.';
                $this->claseMensaje = 'errors';
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $this->view->title = "ExpressAuto - Editar reserva";

        $request = $this->getRequest();
        $form = new Default_Form_Reserva('/demo/index#reservas');
        $form->setAction('/demo-reserva/edit');
        $form->submit->setLabel('Editar reserva');
        $form->vehiculo->addMultiOptions(Default_Model_DemoVehiculo::getPairsToSelect($this->usuario->cliente));

        if ($this->_request->isPost()) {
            if ($form->isValid($request->getPost())) {

                $id = (int)$form->getValue('id');

                $reserva = new Default_Model_DemoReserva();
                $where = $reserva->getAdapter()->quoteInto("id=?", $id);
                $row = $reserva->fetchRow($where);
                $row->vehiculo = $form->getValue('vehiculo');
                $row->usuario_id = $this->usuario->id;
                $row->fecha = $form->getValue('fecha');
                $row->hora = $form->getValue('hora');
                if($form->getValue('comentarios')=='') {
                    $row->comentarios = NULL;
                } else {
                    $row->comentarios = $form->getValue('comentarios');
                }
                $row->tipo = $form->getValue('tipo');
                $row->save();

                $mSession->mensajes[] = 'La reserva fue editada de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_redirect('/demo/index#reservas');
                
            } else {
                $form->populate($request->getPost());
            }

        } else {

            $id = (int)$this->_getParam('id');
            $reserva = new Default_Model_DemoReserva();
            $where = $reserva->getAdapter()->quoteInto("id=?", $id);
            $registro = $reserva->fetchRow($where);
            $form->populate($registro->toArray());
        }
        $this->view->form = $form;
    }

    public function cancelAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_request->getParam('id', 0);

        $reserva = new Default_Model_DemoReserva();
        $reserva->setId($id);
        if($reserva->getEstado()=='Aprobada') {
            $row = $reserva->fetchRow('reserva_id='.$id);
            $row->estado = 'Cancelada';
            $row->save();
            $mSession->mensajes = array('La reserva fue cancelada de forma exitosa.');
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/demo/index#reservas');
        }
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_request->getParam('id', 0);

        $reserva = new Default_Model_DemoReserva();
        $where = $reserva->getAdapter()->quoteInto("id=?", $id);
        $row = $reserva->fetchRow($where);
        if($row->estado=='PENDIENTE') {
            $reserva->delete($where);
            $mSession->mensajes = array('La reserva fue eliminada de forma exitosa.');
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/demo/index#reservas');
        } else {
            $this->_redirect('/demo/index#reservas');
        }
    }
}