<?php
class ModuloClienteController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $action = $this->getRequest()->getActionName();
        $auth = Zend_Auth::getInstance();
        if (!$auth->hasIdentity()) {
            $this->_redirect('/iniciar-sesion');
        } else {
            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->type_session=='demo') {
                $this->_redirect('/');
            }
        }
    }
    
    public function init()
    {
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $response = $this->getResponse();
        $response->insert('header', $this->view->render('header-user.phtml'));
        $response->insert('footer', $this->view->render('footer.phtml'));
    }

    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($this->usuario->estado=='DESHABILITADO'){
            $mSession->mensajes[] = 'El usuario se encuentra deshabilitado para ingresar.';
            $mSession->claseMensaje = 'errors';
            $this->_redirect('/acceso/logout');
        }

        if($this->usuario->tipo_acceso_web=='MULTIUSUARIO') {
            switch ($this->usuario->tipo){
                case "ADMINISTRADOR" :
                    $redir = '/modulo-cliente/admin';
                    break;
                case "CONDUCTOR" :
                    $redir = '/modulo-cliente/conductor';
                    break;
                default :
                    $redir = '/acceso/logout';
            }
        } elseif($this->usuario->tipo_acceso_web=='MONOUSUARIO'){
            $redir = '/modulo-cliente/base';
        } else {
            $redir = '/acceso/logout';
        }
        $this->_redirect($redir);
    }

    public function adminAction()
    {
        if($this->usuario->tipo!='ADMINISTRADOR'){
            $this->_redirect('/acceso/logout');
        }

        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $this->view->title = "ExpressAuto S.p.A. - Módulo cliente - Administración de flota";

        $cliente = new Default_Model_VistaClientes();
        $whereCliente = $cliente->getAdapter()->quoteInto("rut=?", $this->usuario->cliente);
        $this->view->cliente = $cliente->fetchRow($whereCliente);

        $vehiculo = new Default_Model_VistaVehiculos();
        $whereVehiculos = $vehiculo->getAdapter()->quoteInto("cliente_id=?", $this->usuario->cliente);
        $this->view->vehiculos = $vehiculo->fetchAll($whereVehiculos);

        $reserva = new Default_Model_VistaReservas();
        $whereReservas = $reserva->getAdapter()->quoteInto("rut=?", $this->usuario->cliente);
        $orderReservas = "";
        $this->view->reservas = $reserva->fetchAll($whereReservas, $orderReservas);

        $usuario = new Default_Model_VistaUsuarios();
        $whereUsuarios = $usuario->getAdapter()->quoteInto("cliente=?", $this->usuario->cliente);
        $this->view->usuarios = $usuario->fetchAll($whereUsuarios);

        if($_POST){
            $validadorFecha = new Zend_Validate_Date();
            $servicio = new Default_Model_VistaServicios();
            $where = $servicio->getAdapter()->quoteInto("cliente=?", $this->usuario->cliente);
            $vehiculo = $this->_getParam('vehiculo');
            if($this->_helper->validateRecordExists('vehiculos', 'patente', $vehiculo)){
                $where .= " AND vehiculo='$vehiculo'";
                $this->view->vehiculo = $vehiculo;
            }
            if($this->_getParam('fecha_i')!=''){
                if($validadorFecha->isValid($this->_getParam('fecha_i'))){
                    $fecha_i = $this->_getParam('fecha_i') . ' 00:00:00';
                    $where .= " AND fecha_termino >= '$fecha_i'";
                    $this->view->fecha_i = $this->_getParam('fecha_i');
                }
            }
            if($this->_getParam('fecha_t')!=''){
                if($validadorFecha->isValid($this->_getParam('fecha_t'))){
                    $fecha_t = $this->_getParam('fecha_t') . ' 00:00:00';
                    $where .= " AND fecha_termino <= '$fecha_t'";
                    $this->view->fecha_t = $this->_getParam('fecha_t');
                }
            }
            $servicios = $servicio->fetchAll($where);
            $this->view->servicios = $servicios;
        }
    }

    public function conductorAction()
    {
        if($this->usuario->tipo!='CONDUCTOR' ){
            $this->_redirect('/acceso/logout');
        }

        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $this->view->title = "ExpressAuto S.p.A. - Módulo usuario";

        $cliente = new Default_Model_VistaClientes();
        $whereCliente = $cliente->getAdapter()->quoteInto("rut=?", $this->usuario->cliente);
        $this->view->cliente = $cliente->fetchRow($whereCliente);

        $vehiculo = new Default_Model_VistaVehiculos();
        $whereVehiculos = $vehiculo->getAdapter()->quoteInto("cliente_id=?", $this->usuario->cliente);
        $this->view->vehiculos = $vehiculo->fetchAll($whereVehiculos);

        $reserva = new Default_Model_VistaReservas();
        $whereReservas = $reserva->getAdapter()->quoteInto("rut=?", $this->usuario->cliente);
        $orderReservas = "";
        $this->view->reservas = $reserva->fetchAll($whereReservas, $orderReservas);
        
        if($_POST){
            $validadorFecha = new Zend_Validate_Date();
            $servicio = new Default_Model_VistaServicios();
            $where = $servicio->getAdapter()->quoteInto("cliente=?", $this->usuario->cliente);
            $vehiculo = $this->_getParam('vehiculo');
            if($this->_helper->validateRecordExists('vehiculos', 'patente', $vehiculo)){
                $where .= " AND vehiculo='$vehiculo'";
                $this->view->vehiculo = $vehiculo;
            }
            if($this->_getParam('fecha_i')!=''){
                if($validadorFecha->isValid($this->_getParam('fecha_i'))){
                    $fecha_i = $this->_getParam('fecha_i') . ' 00:00:00';
                    $where .= " AND fecha_termino >= '$fecha_i'";
                    $this->view->fecha_i = $this->_getParam('fecha_i');
                }
            }
            if($this->_getParam('fecha_t')!=''){
                if($validadorFecha->isValid($this->_getParam('fecha_t'))){
                    $fecha_t = $this->_getParam('fecha_t') . ' 00:00:00';
                    $where .= " AND fecha_termino <= '$fecha_t'";
                    $this->view->fecha_t = $this->_getParam('fecha_t');
                }
            }
            $servicios = $servicio->fetchAll($where);
            $this->view->servicios = $servicios;
        }
    }

    public function baseAction()
    {
        if($this->usuario->tipo!='ADMINISTRADOR' ){
            $this->_redirect('/acceso/logout');
        }

        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $this->view->title = "ExpressAuto S.p.A. - Módulo usuario";

        $cliente = new Default_Model_VistaClientes();
        $whereCliente = $cliente->getAdapter()->quoteInto("rut=?", $this->usuario->cliente);
        $this->view->cliente = $cliente->fetchRow($whereCliente);

        $vehiculo = new Default_Model_VistaVehiculos();
        $whereVehiculos = $vehiculo->getAdapter()->quoteInto("cliente_id=?", $this->usuario->cliente);
        $this->view->vehiculos = $vehiculo->fetchAll($whereVehiculos);

        $reserva = new Default_Model_VistaReservas();
        $whereReservas = $reserva->getAdapter()->quoteInto("rut=?", $this->usuario->cliente);
        $orderReservas = "";
        $this->view->reservas = $reserva->fetchAll($whereReservas, $orderReservas);

        if($_POST){
            $validadorFecha = new Zend_Validate_Date();
            $servicio = new Default_Model_VistaServicios();
            $where = $servicio->getAdapter()->quoteInto("cliente=?", $this->usuario->cliente);
            $vehiculo = $this->_getParam('vehiculo');
            if($this->_helper->validateRecordExists('vehiculos', 'patente', $vehiculo)){
                $where .= " AND vehiculo='$vehiculo'";
                $this->view->vehiculo = $vehiculo;
            }
            if($this->_getParam('fecha_i')!=''){
                if($validadorFecha->isValid($this->_getParam('fecha_i'))){
                    $fecha_i = $this->_getParam('fecha_i') . ' 00:00:00';
                    $where .= " AND fecha_termino >= '$fecha_i'";
                    $this->view->fecha_i = $this->_getParam('fecha_i');
                }
            }
            if($this->_getParam('fecha_t')!=''){
                if($validadorFecha->isValid($this->_getParam('fecha_t'))){
                    $fecha_t = $this->_getParam('fecha_t') . ' 00:00:00';
                    $where .= " AND fecha_termino <= '$fecha_t'";
                    $this->view->fecha_t = $this->_getParam('fecha_t');
                }
            }
            $servicios = $servicio->fetchAll($where);
            $this->view->servicios = $servicios;
        }
    }

    public function configurarOpcionesAction()
    {
        if($this->usuario->tipo!='ADMINISTRADOR'){
            $this->_redirect('/acceso/logout');
        }
        
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $cliente = new Default_Model_Cliente();
        $where = $cliente->getAdapter()->quoteInto("rut=?", $this->usuario->cliente);
        $row = $cliente->fetchRow($where);

        $prefCT = $this->_getParam('cotizacion');
        $prefFT = $this->_getParam('factura');

        $opcionesPrefCotizacion = array('EMAIL', 'TELEFONO', 'FAX');
        $opcionesPrefFactura = array('INMEDIATA', 'CORREO');

        if(in_array($prefCT, $opcionesPrefCotizacion) && in_array($prefFT, $opcionesPrefFactura)) {
            $prefCotizacion = $prefCT;
            $prefFactura = $prefFT;
        } else {
            $prefCotizacion = 'EMAIL';
            $prefFactura = 'INMEDIATA';
        }

        if($row){

            $row->recep_cotizaciones = $prefCotizacion;
            $row->recep_facturas = $prefFactura;
            if($this->_getParam('direccion')!=''){
                $row->direccion_despacho_docs = $this->_getParam('direccion');
            }
            $row->save();
            $mSession->mensajes[] = 'Su preferencia ha sido guardada satisfactoriamente.';
            $mSession->claseMensaje = 'confirmacion';

        } else {
            $this->_redirect('/modulo-cliente');
        }
        $this->_redirect('/modulo-cliente/admin#opciones-cliente');
    }

    public function exportarPdfAction()
    {
        if($this->usuario->tipo!='ADMINISTRADOR'){
            $this->_redirect('/acceso/logout');
        }
        
        $validadorFecha = new Zend_Validate_Date();
        $date = date("Y-m-d");

        if($this->_helper->validateRecordExists('vehiculos', 'patente', $this->_getParam('vehiculo'))){
            $vehiculo = $this->_getParam('vehiculo');
        } else {
            $vehiculo = '0';
        }
        if($this->_getParam('fecha_i')!='' && $validadorFecha->isValid($this->_getParam('fecha_i'))){
            $fecha_i = $this->_getParam('fecha_i');
        } else {
            $fecha_i = '0';
        }
        if($this->_getParam('fecha_t')!='' && $validadorFecha->isValid($this->_getParam('fecha_t'))){
            $fecha_t = $this->_getParam('fecha_t');
        } else {
            $fecha_t = '0';
        }

        $html = $this->_armarHtmlToPdf($vehiculo, $fecha_i, $fecha_t);
        $dompdf = new DOMPDF();
        $dompdf->load_html($html);
        $dompdf->set_paper('letter', 'portrait');
        $dompdf->render();
        $document = $dompdf->output();
        header('Content-disposition: attachment; filename=' . 'informe-servicios_' . $date .'.pdf');
        header('Content-Type: application/octet-stream; charset=utf-8');
        header('Content-Length: '. strlen($document));
        header('Pragma: no-cache');
        header('Cache-Control: no-store, no-cache, must-revalidate, post-check=0, pre-check=0');
        header('Expires: 0');
        die($document);
    }

    public function exportarXlsAction()
    {
        if($this->usuario->tipo!='ADMINISTRADOR'){
            $this->_redirect('/acceso/logout');
        }
        
        $this->_helper->layout->disableLayout(true);
        $this->_helper->viewRenderer->setNoRender(true);
        $this->_helper->layout->setLayout('xls');

        $vehiculo = $this->_getParam('vehiculo');

        $cliente = new Default_Model_VistaClientes();
        $whereCliente = $cliente->getAdapter()->quoteInto("rut=?", $this->usuario->cliente);
        $rowCliente = $cliente->fetchRow($whereCliente);

        $modelServicio = new Default_Model_VistaServicios();
        $where = $modelServicio->getAdapter()->quoteInto("cliente=?", $this->usuario->cliente);

        if($this->_helper->validateRecordExists('vehiculos', 'patente', $vehiculo)){
            $where .= " AND vehiculo='$vehiculo'";
            $this->view->vehiculo = $vehiculo;
        }

        $validadorFecha = new Zend_Validate_Date();

        if($this->_getParam('fecha_i')!=''){
            if($validadorFecha->isValid($this->_getParam('fecha_i'))){
                $fecha_i = $this->_getParam('fecha_i') . ' 00:00:00';
                $where .= " AND fecha_termino >= '$fecha_i'";
                $this->view->fecha_i = $this->_getParam('fecha_i');
            }
        }

        if($this->_getParam('fecha_t')!=''){
            if($validadorFecha->isValid($this->_getParam('fecha_t'))){
                $fecha_t = $this->_getParam('fecha_t') . ' 00:00:00';
                $where .= " AND fecha_termino <= '$fecha_t'";
                $this->view->fecha_t = $this->_getParam('fecha_t');
            }
        }
        
        $servicios = $modelServicio->fetchAll($where);

        $data = '<table border="1" cellpadding="3">
                 <caption align="left">
                    Informe Servicios | Cliente: ' . $rowCliente->nombre .' / ' . $this->view->formatRut($rowCliente->rut) . '
                 </caption>
                 <thead>
                 <tr>
                 <th align="left">Vehículo</th>
                 <th align="left">Fecha</th>
                 <th align="left">Factura</th>
                 <th>Monto c/IVA</th>
                 <th align="left">Trabajo realizado</th>
                 <th align="left">Informe</th>
                 <th align="left">Recomendaciones</th>
                 </tr>
                 </thead>';

        foreach($servicios as $servicio) {
            $data .= '<tbody>
                      <tr>
                      <td>' . $servicio->vehiculo . '</td>
                      <td align="left">' . $this->view->formatFecha($servicio->fecha_termino) . '</td>
                      <td></td>
                      <td></td>
                      <td>' . $servicio->nombre . "\n" . nl2br($servicio->descripcion) . '</td>
                      <td>' . nl2br($servicio->observaciones) . '</td>
                      <td>' . nl2br($servicio->recomendaciones) . '</td>
                      </tr>
                      </tbody>';
        }
        $data .= '</table>';

        header('Content-type: application/vnd.ms-excel');
        header("Content-Disposition: attachment; filename=informe-servicios.xls");
        header("Pragma: no-cache");
        header("Expires: 0");
        echo $data;
    }

    private function _armarHtmlToPdf($vehiculo, $fecha_i, $fecha_t)
    {
        $cliente = new Default_Model_VistaClientes();
        $whereCliente = $cliente->getAdapter()->quoteInto("rut=?", $this->usuario->cliente);
        $servicio = new Default_Model_VistaServicios();
        $where = $servicio->getAdapter()->quoteInto("cliente=?", $this->usuario->cliente);
        if($vehiculo!='0'){
            $where .= " AND vehiculo='$vehiculo'";
        }
        if($fecha_i!='0'){
            $fecha_i = $this->_getParam('fecha_i') . ' 00:00:00';
            $where .= " AND fecha_termino >= '$fecha_i'";
        }
        if($fecha_t!='0'){
            $fecha_t = $fecha_t . ' 00:00:00';
            $where .= " AND fecha_termino <= '$fecha_t'";
        }

        $rowCliente = $cliente->fetchRow($whereCliente);
        $rowsServicios = $servicio->fetchAll($where);

        $data  = '<html><head>';
        $data .= '<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />';
        $data .= '<title>Informe de servicios</title>';
        $data .= '<style type="text/css">';
        $data .= 'html, * {font: 11px Arial,Helvetica,sans-serif;}';
        $data .= 'body {color:#333;margin:0;text-align:center;}';
        $data .= 'div {text-align:left;}';
        $data .= 'h1,h2,h3 {font-weight:normal;font-family:"Trebuchet MS","Gill Sans", Arial, Verdana,  sans-serif;}';
        $data .= 'table, ul {font-size:85%;}';
        $data .= '#documento {position:relative;width:200mm;margin:3mm auto;}';
        $data .= '#top {position:relative;border-bottom:#333 solid 2px;color:#888;}';
        $data .= '#fecha {position:absolute;right:0;top:0;}';
        $data .= '#header {position:relative;margin:1mm 0;width:100%;background:url("/img/logo-pdf.png") no-repeat right top;}';
        $data .= '#header h1 {font-size:1.7em;padding:27px 0 20px 0;margin:0;color:#000;}';
        $data .= '.border-right {border-right:#aaa solid 1px;}';
        $data .= '.border-left {border-left:#aaa solid 1px;}';
        $data .= '.border-top {border-top:#aaa solid 1px;}';
        $data .= '.border-bottom {border-bottom:#aaa solid 1px;}';
        $data .= 'table.documento {margin:0;width:100%;border-collapse: collapse;border-top:#aaa solid 1px;border-right:#aaa solid 1px;border-left:#aaa solid 1px;}';
        $data .= 'table.documento thead {border-bottom:#aaa solid 1px;background-color: #eee;}';
        $data .= 'table.documento thead th {padding:1mm;}';
        $data .= 'table.documento tbody tr th, table.documento tbody tr td {vertical-align: top;padding:1mm;}';
        $data .= 'table.documento tbody tr td {border-bottom:#aaa solid 1px;}</style>';
        $data .= '</head>';
        $data .= '<body>';
        $data .= '<div id="documento"><div id="top">';
        $data .= '<table width="100%">';
        $data .= '<tr><td>' . $this->view->escape($rowCliente->nombre) . ' / ' . $this->view->formatRut($rowCliente->rut) .'</td>';
        $data .= '<td align="right">' . $this->view->formatFecha(date("Y-m-d")) . '</td></tr>';
        $data .= '</table></div>';
        $data .= '<div id="header"><h1>Informe de servicios</h1></div>';
        $data .= '<table class="documento"><thead><tr>';
        $data .= '<th width="35" align="left" class="border-right">Vehículo</th>';
        $data .= '<th width="70" align="left" class="border-right">Fecha</th>';
        $data .= '<th width="35" align="left" class="border-right">Factura</th>';
        $data .= '<th width="50" class="border-right">Monto c/IVA</th>';
        $data .= '<th align="left" class="border-right">Trabajo realizado</th>';
        $data .= '<th align="left" class="border-right">Informe</th>';
        $data .= '<th align="left">Recomendaciones</th>';
        $data .= '</tr></thead><tbody>';
        foreach($rowsServicios as $rowServicio) {
            $data .= '<tr>';
            $data .= '<td class="border-right">' . $this->view->escape($rowServicio->vehiculo) . '</td>';
            $data .= '<td class="border-right">' . $this->view->formatFecha($rowServicio->fecha_termino) . '</td>';
            $data .= '<td class="border-right"></td>';
            $data .= '<td class="border-right"></td>';
            $data .= '<td class="border-right"><strong>' . $this->view->escape($rowServicio->nombre) . '</strong>';
            $data .= '<br />' . nl2br($this->view->escape($rowServicio->descripcion)) . '</td>';
            $data .= '<td class="border-right">' . nl2br($this->view->escape($rowServicio->observaciones)) . '</td>';
            $data .= '<td>' . nl2br($this->view->escape($rowServicio->recomendaciones)) . '</td></tr>';
        }
        $data .= '</tbody></table></div></body></html>';
        return $data;
    }
}