<?php
class RegistroController extends Zend_Controller_Action
{
    public function init()
    {
        $response = $this->getResponse();
        $this->path = '/registro';
        $auth = Zend_Auth::getInstance(); 
        if (!$auth->hasIdentity()) { 
            $response->insert('header', $this->view->render('header.phtml'));     
        } else {
            $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
            $response->insert('header', $this->view->render('header-user.phtml'));    
        }
        $response->insert('footer', $this->view->render('footer.phtml')); 
    }

    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->title = "ExpressAuto S.p.A. - Registro";

        $request = $this->getRequest();
        $form = new Default_Form_Cliente(null, $this->path);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                $optionsCliente = array('table' => 'clientes', 'field' => 'rut');
                $validadorCliente = new Zend_Validate_Db_NoRecordExists($optionsCliente);

                if($validadorCliente->isValid(App_Rut::cleanToDb($form->getValue('rut')))) {

                    $cliente = new Default_Model_Cliente();
                    $db = $cliente->getAdapter();
                    $db->beginTransaction();

                    try {

                        $rut = App_Rut::cleanToDb($form->getValue('rut'));
                        $row = $cliente->createRow();
                        $row->nombre = $form->getValue('nombre');
                        $row->rut = $rut;
                        $row->direccion = $form->getValue('direccion');
                        $row->comuna = $form->getValue('comuna');
                        $row->ciudad = $form->getValue('ciudad');
                        $row->telefono = $form->getValue('telefono');
                        $row->mail = $form->getValue('mail');
                        $row->web = $form->getValue('web');
                        $row->tipo_registro = 'WEB';
                        $row->estado_registro = 0;
                        $row->save();

                        $usuario = new Default_Model_Usuario();
                        $rowUsuario = $usuario->createRow();
                        $rowUsuario->cliente = $rut;
                        $rowUsuario->nombre = $form->getValue('nombre');
                        $rowUsuario->mail = $form->getValue('mail');
                        $rowUsuario->telefono = $form->getValue('telefono');
                        $rowUsuario->tipo = 'ADMINISTRADOR';
                        $rowUsuario->estado = 'DESHABILITADO';
                        $rowUsuario->clave = '000000';
                        $rowUsuario->save();

                        $semilla = $rut . 'suma';
                        $suma = md5($semilla);
                        $enlace = 'http://www.expressauto.cl/registro/c/' . $rowUsuario->id  . '/' . $rut . '/' . $suma ;

                        $mail = new App_HtmlMailer('UTF-8');
                        $mail->setSubject('Confirmación de registro')
                             ->addTo($row->mail)
                             ->setViewParam('enlace', $enlace)
                             ->setViewParam('nombre', $form->getValue('nombre'))
                             ->sendHtmlTemplate('confirmacion-registro.phtml');

                        $db->commit();
                        $this->_redirect('/registro/aviso-conf');

                    } catch (Exception $e) {
                        $db->rollBack();
                        $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                        $mSession->mensajes[] = $e->getMessage();
                        $mSession->claseMensaje = 'error';
                        $this->_redirect('/registro');
                    }
                } else {
                    $this->_redirect('/registro/cliente-existe');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
            }
        } 
        $this->view->form = $form;
    }

    public function confirmacionAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        $this->view->title = "ExpressAuto S.p.A. - Registro";

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->title = "ExpressAuto S.p.A. - Confirmación de registro";
        
        $rut = App_Rut::cleanToDb($this->_getParam('cliente'));
        $usuario = (int)$this->_getParam('usuario');
        $sum = $this->_request->getParam('suma');

        $optionsRut = array('table' => 'clientes', 'field' => 'rut');
        $optionsUsuario = array('table' => 'usuarios_web', 'field' => 'id');

        $validadorRut = new Zend_Validate_Db_RecordExists($optionsRut);
        $validadorUsuario = new Zend_Validate_Db_RecordExists($optionsUsuario);

        if ($validadorRut->isValid($rut) AND $validadorUsuario->isValid($usuario)) {
            
            $cliente = new Default_Model_Cliente();
            $where = $cliente->getAdapter()->quoteInto("rut=?", $rut);
            $row_cliente = $cliente->fetchRow($where);

            $semilla = md5($row_cliente->rut . 'suma');
            $password = new App_Password($semilla, 8);
            $clave = $password->getPassword();
            $claveEncriptada = md5($clave);

            if($semilla==$sum AND $row_cliente->estado_registro=='0') {

                $row_cliente->estado_registro = '1';
                $row_cliente->save();

                $usuario = new Default_Model_Usuario();
                $whereUsuario = $usuario->getAdapter()->quoteInto("cliente=?", $rut);
                $row_usuario = $usuario->fetchRow($whereUsuario);
                $row_usuario->clave = $claveEncriptada;
                $row_usuario->estado = 'HABILITADO';
                $row_usuario->save();

                $form = new Default_Form_Acceso();
                $this->view->clave = $clave;
                $this->view->form = $form;

            } elseif($semilla==$sum AND $row_cliente->estado=='1')  {
                 $this->renderScript('/registro/aviso.phtml');
            } else {
                $this->_redirect('/registro/index');
            }
            
        } else {
            $this->_redirect('/registro/aviso-error-auth');
        }
    }

    public function confirmacionInternaAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        $this->view->title = "ExpressAuto S.p.A. - Registro";

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $this->view->title = "ExpressAuto S.p.A. - Confirmación de registro";

        $rut = App_Rut::cleanToDb($this->_getParam('cliente'));
        $usuario = (int)$this->_getParam('usuario');
        $sum = $this->_getParam('suma');

        $optionsRut = array('table' => 'clientes', 'field' => 'rut');
        $optionsUsuario = array('table' => 'usuarios_web', 'field' => 'id');

        $validadorRut = new Zend_Validate_Db_RecordExists($optionsRut);
        $validadorUsuario = new Zend_Validate_Db_RecordExists($optionsUsuario);

        if ($validadorRut->isValid($rut) AND $validadorUsuario->isValid($usuario)) {

            $cliente = new Default_Model_Cliente();
            $where = $cliente->getAdapter()->quoteInto("rut=?", $rut);
            $row_cliente = $cliente->fetchRow($where);

            $semilla = md5($row_cliente->rut . 'suma');
            $password = new App_Password($semilla, 8);
            $userPass = $password->getPassword();

            if($semilla==$sum) {

                $usuario = new Default_Model_Usuario();
                $whereUsuario = $usuario->getAdapter()->quoteInto("cliente=?", $rut);
                $row_usuario = $usuario->fetchRow($whereUsuario);
                $row_usuario->clave = md5($userPass);
                $row_usuario->estado = 'HABILITADO';
                $row_usuario->save();

                $form = new Default_Form_Acceso();
                $this->view->clave = $userPass;
                $this->view->form = $form;

            } elseif($semilla==$sum AND $row_cliente->estado=='1')  {
                 $this->renderScript('/registro/aviso.phtml');
            } else {
                $this->_redirect('/registro/index');
            }
        } else {
            $this->_redirect('/registro/aviso-error-auth');
        }
    }

    public function avisoConfAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        $this->view->title = "ExpressAuto S.p.A. - Registro";
        $this->view->enlace = $mSession->enlace;

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

    }

    public function clienteExisteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        $this->view->title = "ExpressAuto S.p.A. - Registro";

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
    }

    public function testPasswordAction()
    {
        $password = new App_Password('abscvvfrde', 8);
        $this->view->password = $password->getPassword();
    }
}