<?php
class Default_Form_Reserva extends Zend_Form
{ 
    public function __construct($back, $options = null)
    { 
        parent::__construct($options);
        
        $tipos = array(
            'MANT PROGRAMADO' => 'Mantenimiento Programado',
            'REV GENERAL' => 'Revisión General',
            'REPARACION' => 'Reparación',
            'OTRO' => 'Otro motivo'
        );

        $optionsVehiculo = array('table' => 'vehiculos', 'field' => 'patente');
        $validadorVehiculo = new Zend_Validate_Db_RecordExists($optionsVehiculo);

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');

        $vehiculo = new Zend_Form_Element_Select('vehiculo');
        $vehiculo->setLabel('Vehículo')
              ->setRequired(true)
              ->addMultiOption('','- Seleccionar -')
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addValidator($validadorVehiculo);
              
        $fecha = new Zend_Form_Element_Text('fecha');
        $fecha->setLabel('Fecha')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addValidator('Date');
              
        $hora = new Zend_Form_Element_Select('hora');
        $hora->setLabel('Hora')
            ->setRequired(true)
            ->addFilter('StripTags') 
            ->addFilter('StringTrim')
            ->addMultiOption('','--Seleccionar')
            ->addMultiOptions(array(
                '08:00:00'  => '08:00',
                '09:00:00'  => '09:00',
                '10:00:00'  => '10:00',
                '11:00:00'  => '11:00',
                '12:00:00'  => '12:00',
                '13:00:00'  => '13:00'));
           
        $comentarios = new Zend_Form_Element_Textarea('comentarios');
        $comentarios->setLabel('Comentarios')
              ->setRequired(false)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->setAttrib('style', 'width:300px;height:175px;');
              
        $tipo = new Zend_Form_Element_Select('tipo');
        $tipo->setLabel('Tipo')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addMultiOption('','- Seleccionar -')
              ->addMultiOptions($tipos);
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear reserva')
                ->setAttrib('class', 'submit-button')
                ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('rel', $back)
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $id, $vehiculo, $tipo, $comentarios,
                $fecha, $hora, $submit, $cancel
            )
        );
            
        $this->addDisplayGroup(
            array(
                'vehiculo', 'tipo', 'fecha', 'hora'
            ),
            'grupo1'
        );

        $grupo1 = $this->getDisplayGroup('grupo1');
        $grupo1->setDecorators(
                array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array(
                'comentarios'
            ),
            'grupo2'
        );

        $grupo2 = $this->getDisplayGroup('grupo2');
        $grupo2->setDecorators(
                array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array(
                'submit', 'cancel', 'id'
            ),
            'gsubmit'
        );

        $gsubmit = $this->getDisplayGroup('gsubmit');
        $gsubmit->setDecorators(
                array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            )
        );

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido',
                'name'      => 'freserva',
                'action'    => '/reserva/new'
            ));
    } 
} 
