<?php
class Default_Form_Usuario extends Zend_Form
{ 
    public function __construct($back, $options = null)
    { 
        parent::__construct($options);

        $optionsEmail = array('table' => 'usuarios_web', 'field' => 'mail');
        $validadorEmail = new Zend_Validate_Db_NoRecordExists($optionsEmail);

        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
              
        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim');

        $tipo = new Zend_Form_Element_Select('tipo');
        $tipo->setLabel('Tipo')
            ->setRequired(true)
            ->addFilter('StripTags')
            ->addFilter('StringTrim')
            ->addMultiOption('','- Seleccionar -')
            ->addMultiOption('ADMINISTRADOR','ADMINISTRADOR')
            ->addMultiOption('CONDUCTOR','CONDUCTOR')
            ->setAttrib('class','disable');
              
        $telefono = new Zend_Form_Element_Text('telefono');
        $telefono->setLabel('Teléfono')
              ->addFilter('StripTags') 
              ->addFilter('StringTrim');
              
        $mail = new Zend_Form_Element_Text('mail');
        $mail->setLabel('Email')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator('EmailAddress')
              ->addValidator($validadorEmail)
              ->setErrorMessages(array('Por favor ingrese una dirección de email válida', 'error'));
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear usuario')
               ->setAttrib('class', 'submit-button')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('rel', $back)
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $tipo, $nombre, $telefono, $mail, $submit, $id, $cancel
            )
        );

        $this->addDisplayGroup(
            array(
                'nombre', 'tipo', 'mail','clave1','clave2'
            ),
            'grupo1'
        );

        $grupo1 = $this->getDisplayGroup('grupo1');
        $grupo1->setDecorators(
                array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array(
                'telefono'
            ),
            'grupo2'
        );

        $grupo2 = $this->getDisplayGroup('grupo2');
        $grupo2->setDecorators(
                array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left2'))
            )
        );

        $this->addDisplayGroup(
            array(
                'submit', 'cancel', 'id'
            ),
            'gsubmit'
        );

        $gsubmit = $this->getDisplayGroup('gsubmit');
        $gsubmit->setDecorators(
                array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            )
        );

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido',
                'name'      => 'form-usuario',
                'action'    => '/usuario/new'
            ));

    } 
} 
