<?php
class Default_Form_Vehiculo extends Zend_Form
{ 
    public function __construct($back, $options = null)
    { 
        parent::__construct($options);
        
        $opcionesValidadorMarca = array('table' => 'marcas_vehiculos', 'field' => 'id');
        $validadorMarca = new Zend_Validate_Db_RecordExists($opcionesValidadorMarca);
        $validadorCilindrada = new App_Validate_Float();

        $patente = new Zend_Form_Element_Text('patente');
        $patente->setLabel('Patente')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addFilter('StringToUpper')
              ->addFilter('Alnum')
              ->addValidator('StringLength', null, array( 'min' => 6, 'max' => 6));
              
        $marca_id = new Zend_Form_Element_Select('marca_id');
        $marca_id->setLabel('Marca')
                 ->setRequired(true)
                 ->addMultiOption('','- Seleccionar -')
                 ->addMultiOptions(Default_Model_MarcaVehiculo::getPairsToSelect())
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator($validadorMarca);
           
        $modelo = new Zend_Form_Element_Text('modelo');
        $modelo->setLabel('Modelo Vehículo')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');

        $version = new Zend_Form_Element_Text('version');
        $version->setLabel('Versión')
                ->setRequired(false)
                ->addFilter('StripTags')
                ->addFilter('StringTrim');

        $cilindrada = new Zend_Form_Element_Text('cilindrada');
        $cilindrada->setLabel('Cilindrada')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator($validadorCilindrada);

        $tipo_combustible = new Zend_Form_Element_Select('tipo_combustible');
        $tipo_combustible->setLabel('Tipo combustible')
                         ->setRequired(true)
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim')
                         ->addMultiOption('','-- Seleccionar --')
                         ->addMultiOption('GASOLINA','GASOLINA')
                         ->addMultiOption('DIESEL','DIESEL')
                         ->addMultiOption('ETANOL','ETANOL')
                         ->addMultiOption('ALCOHOL','ALCOHOL');

        $traccion = new Zend_Form_Element_Select('traccion');
        $traccion->setLabel('Tracción')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addMultiOption('','-- Seleccionar --')
                 ->addMultiOption('4x2','4x2')
                 ->addMultiOption('4x4','4x4');

        $transmision = new Zend_Form_Element_Select('transmision');
        $transmision->setLabel('Transmisión')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addMultiOption('','-- Seleccionar --')
                 ->addMultiOption('MANUAL','MANUAL')
                 ->addMultiOption('AUTOMATICA','AUTOMATICA');
              
        $anio = new Zend_Form_Element_Text('anio');
        $anio->setLabel('Año')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator('Int')
              ->addValidator('Between', null, array('min' => 1980, 'max' => date("Y")));

        $color = new Zend_Form_Element_Text('color');
        $color->setLabel('Color')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim');

        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Agregar vehículo')
               ->setAttrib('class', 'submit-button')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('rel', $back)
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $patente, $marca_id, $modelo, $version,
                $cilindrada, $tipo_combustible, $traccion,
                $transmision, $anio, $color, $submit, 
                $cancel));

        $this->addDisplayGroup(
            array(
                'patente', 'marca_id', 'modelo', 'version', 'cilindrada'
            ),
            'grupo1'
        );

        $grupo1 = $this->getDisplayGroup('grupo1');
        $grupo1->setDecorators(
                array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array(
                'tipo_combustible', 'traccion', 'transmision', 'anio', 'color'
            ),
            'grupo2'
        );

        $grupo2 = $this->getDisplayGroup('grupo2');
        $grupo2->setDecorators(
                array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array(
                'submit', 'cancel'
            ),
            'gsubmit'
        );

        $gsubmit = $this->getDisplayGroup('gsubmit');
        $gsubmit->setDecorators(
                array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            )
        );

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido',
                'name'      => 'vehiculo',
                'action'    => '/vehiculo/new'
            ));

    } 
} 
